@@ -403,7 +403,8 @@ class TestSceneConfig(unittest.TestCase):
                     'x': 0.07,
                     'y': 0.08,
                     'z': 0.09
-                }
+                },
+                'globalSpace': True
             }],
             'nullParent': {
                 'position': {
@@ -492,6 +493,7 @@ class TestSceneConfig(unittest.TestCase):
                     'z': 0.43
                 }
             }],
+            "triggeredBy": True,
             'togglePhysics': [{
                 'stepBegin': 27
             }],
@@ -564,6 +566,7 @@ class TestSceneConfig(unittest.TestCase):
         self.assertIsNone(object_1.shrouds)
         self.assertIsNone(object_1.states)
         self.assertIsNone(object_1.structure)
+        self.assertIsNone(object_1.triggered_by)
         self.assertIsNone(object_1.teleports)
         self.assertIsNone(object_1.toggle_physics)
         self.assertIsNone(object_1.torques)
@@ -657,7 +660,8 @@ class TestSceneConfig(unittest.TestCase):
         self.assertEqual(object_2.moves, [MoveConfig(
             step_begin=16,
             step_end=17,
-            vector=Vector3d(x=0.07, y=0.08, z=0.09)
+            vector=Vector3d(x=0.07, y=0.08, z=0.09),
+            global_space=True
         )])
         self.assertEqual(object_2.null_parent, TransformConfig(
             position=Vector3d(x=0.11, y=0.12, z=0.13),
@@ -714,6 +718,8 @@ class TestSceneConfig(unittest.TestCase):
             step_begin=26,
             position=Vector3d(x=0.41, y=0.42, z=0.43)
         )])
+        self.assertEqual(
+            object_2.triggered_by, True)
         self.assertEqual(
             object_2.toggle_physics, [
                 SingleStepConfig(
@@ -724,6 +730,33 @@ class TestSceneConfig(unittest.TestCase):
             vector=Vector3d(x=0.44, y=0.45, z=0.46)
         )])
 
+    def test_is_passive_scene(self):
+        goal_1 = Goal(category='retrieval')
+        goal_2 = Goal(category='imitation')
+        goal_3 = Goal(category='passive')
+        goal_4 = Goal(category='intuitive physics')
+        goal_5 = Goal(category='agents')
+
+        config_1 = SceneConfiguration(goal=goal_1)
+        config_2 = SceneConfiguration(goal=goal_2)
+        config_3 = SceneConfiguration(goal=goal_3)
+        config_4 = SceneConfiguration(goal=goal_4)
+        config_5 = SceneConfiguration(goal=goal_5)
+
+        assert not config_1.is_passive_scene()
+        assert not config_2.is_passive_scene()
+        assert config_3.is_passive_scene()
+        assert config_4.is_passive_scene()
+        assert config_5.is_passive_scene()
+
+        config_6 = SceneConfiguration()
+        config_7 = SceneConfiguration(intuitive_physics=True)
+        config_8 = SceneConfiguration(isometric=True)
+
+        assert not config_6.is_passive_scene()
+        assert config_7.is_passive_scene()
+        assert config_8.is_passive_scene()
+
     def test_retrieve_goal_with_config_metadata(self):
         # self.controller.set_metadata_tier('oracle')
         goal = {
